==> nextcloud-12.0.2.tgz: nextcloud/apps/activity/l10n/nb.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktiviteter",
    "An error occurred while loading activities" : "En feil oppstod under lasting av aktiviteter",
    "No activity yet" : "Ingen aktivitet ennå",
    "Load more activities" : "Last flere aktiviteter",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "{name} (invisible)" : "{name} (usynlig)",
    "{name} (restricted)" : "{name} (begrenset)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "There are no events for this filter" : "Det er ingen hendelser for dette filteret",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Personal activity feed for %s" : "Personlig aktivitetsstrøm for %s",
    "Your feed URL is invalid" : "Din kilde-URL er ikke gyldig",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Settings have been updated." : "Innstillinger ble oppdatert.",
    "Mail" : "E-post",
    "Stream" : "Strøm",
    "All activities" : "All aktivitet",
    "By others" : "Av andre",
    "By you" : "Av deg",
    "\"remote user\"" : "\"ekstern bruker\"",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Det har vært aktivitet ved %s",
    "_and %n more _::_and %n more _" : ["og %n til","og %n til"],
    "Activity notification" : "Varsel om aktivitet",
    ", " : ", ",
    "%s and %s" : "%s og %s",
    "Activity" : "Aktivitet",
    "Activity feed" : "Aktivitetsstrøm",
    "Configure the default activity settings for new users." : "Konfigurer standard aktivitetsinnstillinger for nye brukere.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Velg hvilke aktiviteter du ha e-mailpåminnelse om, og hvilke som skal vises i aktivitetsapp- strømmen.",
    "List your own actions in the stream" : "List dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Varsle om dine egne handliger via e-post",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send emails:" : "Send e-poster:",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Settings" : "Innstillinger",
    "Enable RSS feed" : "Aktiver RSS-strøm",
    "No more events to load" : "Ingen flere hendelser å laste inn",
    "Files" : "Filer",
    "Error loading activities" : "Feil ved innlasting av aktiviteter",
    "No activities" : "Ingen aktiviteter",
    "You are receiving this email because the following things happened at %s" : "Du mottar denne e-posten fordi følgende har hendt på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og én til","* og %n til "]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/activity/l10n/nb.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktiviteter",
    "An error occurred while loading activities" : "En feil oppstod under lasting av aktiviteter",
    "No activity yet" : "Ingen aktivitet ennå",
    "Load more activities" : "Last flere aktiviteter",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "Home" : "Hjem",
    "{name} (invisible)" : "{name} (usynlig)",
    "{name} (restricted)" : "{name} (begrenset)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "There are no events for this filter" : "Det er ingen hendelser for dette filteret",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Open file" : "Åpne fil",
    "Personal activity feed for %s" : "Personlig aktivitetsnyhetskilde for %s",
    "Your feed URL is invalid" : "Nettadressen for din nyhetskilde er ikke gyldig",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Settings have been updated." : "Innstillinger oppdatert.",
    "All activities" : "All aktivitet",
    "By others" : "Av andre",
    "By you" : "Av deg",
    "\"remote user\"" : "\"ekstern bruker\"",
    "Activity notification for %s" : "Aktivitetsvarsel for %s",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Det har vært aktivitet ved %s",
    "_and %n more _::_and %n more _" : ["og %n til","og %n til"],
    ", " : ", ",
    "%s and %s" : "%s og %s",
    "Mail" : "E-post",
    "Stream" : "Strøm",
    "Activity" : "Aktivitet",
    "Activity feed" : "Aktivitetsnyhetskilde",
    "Send activity emails" : "Send aktivitets-e-poster",
    "Default settings" : "Forvalgte innstillinger",
    "Configure the default activity settings for new users." : "Konfigurer standard aktivitetsinnstillinger for nye brukere.",
    "List your own actions in the stream" : "List dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Varsle om dine egne handliger via e-post",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send emails:" : "Send e-poster:",
    "As soon as possible" : "Så snart som mulig",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Velg hvilke aktiviteter du ha e-mailpåminnelse om, og hvilke som skal vises i aktivitetsapp- strømmen.",
    "Choose which activities you want to see in your stream." : "Velg hvilke aktiviteter du vil se i din strøm.",
    "Settings" : "Innstillinger",
    "Enable RSS feed" : "Aktiver RSS-nyhetskilde",
    "RSS feed" : "RSS-nyhetskilde",
    "No more events to load" : "Ingen flere hendelser å laste inn",
    "Files" : "Filer",
    "Activity notification" : "Varsel om aktivitet"
},
"nplurals=2; plural=(n != 1);");
